///////////////////////////////////////////////////////////////////////////////////
// GameStudio main script
////////////////////////////////////////////////////////////////////////////
// Files to over-ride:
// * logodark.bmp - the engine logo, include your game title
// * horizon.pcx - A horizon map displayed over the sky and cloud maps
////////////////////////////////////////////////////////////////////////////
// The PATH keyword gives directories where game files can be found,
// relative to the level directory
path "C:\\Program Files\\GStudio6\\template";	// Path to WDL templates subdirectory

////////////////////////////////////////////////////////////////////////////
// The INCLUDE keyword can be used to include further WDL files,
// like those in the TEMPLATE subdirectory, with prefabricated actions
var score = 0; // to avoid conflict with war death function
bmap cratepantel = <cratehud2.bmp>;
panel backgroundPcargo
{
	window = 10,10,41,45,cratepantel,0,0;
	pos_x=0;
	pos_y=110;
	flags = refresh, overlay;
}
var cargo = 7;
var canjump = 1;
include <levelchanges.wdl>;
bmap cppanel <checkpointpanel.bmp>;
include <AI.wdl>;
include <mountainsnow.wdl>;
include <movement.wdl>;
include <messages.wdl>;
include <menu.wdl>;		// must be inserted before doors and weapons
include <particle.wdl>; // remove when you need no particles
include <doors.wdl>;		// remove when you need no doors
include <actors.wdl>;   // remove when you need no actors
include <weapons.wdl>;  // remove when you need no weapons

//include <venture.wdl>;	// include when doing an adventure
include <lflare.wdl>;   // remove when you need no lens flares
include <wow.wdl>;
include <endoflevel.wdl>;
include<userctrl.wdl>;
include <transporter.wdl>;
include <checkpoints.wdl>;
include <war.wdl>;      // remove when you need no fighting
////////////////////////////////////////////////////////////////////////////
// The engine starts in the resolution given by the follwing vars.
var video_mode = 6;	 // screen size 640x480
var video_depth = 16; // 16 bit colour D3D mode
var score = 0;
var video_screen = 1;
bmap mainpanel = <newHUD.bmp>;
string partic = <partic.mdl>;
sound coinpickup =<beep2.wav>;
/////////////////////////////////////////////////////////////////
// Strings and filenames
// change this string to your own starting mission message.
string mission_str = "Mountain 2-3";
string level_str = <Mountain2.WMB>; // give file names in angular brackets
string next_level = <Woodland1.WMB>;
/////////////////////////////////////////////////////////////////
// define a splash screen with the required A4/A5 logo
bmap splashmap = <loadscreen.pcx>; // the default logo in templates
panel splashscreen {
	bmap = splashmap;
	flags = refresh,d3d;
}

////////////////////////////////////////////////////////////////////////////
// The following script controls the sky
sky cubesky{	type = <free2+6.tga>;	layer = 1;	material = mat_sky;	flags = cube, visible;}
/////////////////////////////////////////////////////////////////
// The main() function is started at game start
function main()
{
	person_3rd = 0.5;
	// set some common flags and variables
	//	warn_level = 2;	// announce bad texture sizes and bad wdl code
	tex_share = on;	// map entities share their textures

	// center the splash screen for non-640x480 resolutions, and display it
	splashscreen.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen.visible = on;
	// wait 3 frames (for triple buffering) until it is flipped to the foreground
	wait(3);
	max_entities = 4000;
	camera.clip_far = 6000;
	// now load the level

	level_load(level_str);
	// freeze the game
	freeze_mode = 1;

	// wait the required second, then switch the splashscreen off.
	sleep(1);
	splashscreen.visible = off;
	bmap_purge(splashmap);	// remove splashscreen from video memory

	// load some global variables, like sound volume
	load_status();
	media_loop("deeper_underground.midi", NULL, 70);

	// display the initial message
	msg_show(mission_str,10);

	// initialize lens flares when edition supports flares
	ifdef CAPS_FLARE;
		lensflare_start();
	endif;

	// use the new 3rd person camera
	move_view_cap = 1;

	// un-freeze the game
	freeze_mode = 0;
	fps_max = 60;
	fps_min = 30;
	//	client_move();	// for a possible multiplayer game
	// call further functions here...
		init_controls();
}


/////////////////////////////////////////////////////////////////
// The following definitions are for the pro edition window composer
// to define the start and exit window of the application.
WINDOW WINSTART
{
	TITLE			"3D GameStudio";
	SIZE			480,320;
	MODE			IMAGE;	//STANDARD;
	BG_COLOR		RGB(240,240,240);
	FRAME			FTYP1,0,0,480,320;
	//	BUTTON		BUTTON_START,SYS_DEFAULT,"Start",400,288,72,24;
	BUTTON		BUTTON_QUIT,SYS_DEFAULT,"Abort",400,288,72,24;
	TEXT_STDOUT	"Arial",RGB(0,0,0),10,10,460,280;
}

/* no exit window at all..
WINDOW WINEND
{
	TITLE			"Finished";
	SIZE			540,320;
	MODE	 		STANDARD;
	BG_COLOR		RGB(0,0,0);
	TEXT_STDOUT	"",RGB(255,40,40),10,20,520,270;

	SET FONT		"",RGB(0,255,255);
	TEXT			"Any key to exit",10,270;
}*/


/////////////////////////////////////////////////////////////////
//INCLUDE <debug.wdl>;
string scoretext = score;

function pickupcoin
{
	if(event_type == event_TRIGGER && you == player)
	{
		snd_play(coinpickup, 50,0);
		wait(1); // wait one frame before removing an entity in an event function
		score += (1);
		ent_REMOVE(MY);
	}
}

action coin
{
	MY.TRIGGER_RANGE = 34;
	my.enable_TRIGGER = on;
	my.event = pickupcoin;
}


panel displayscore
{
	pos_x = 2;
	pos_y = 2;
	flags = visible,refresh; // make it visible and displayable over the view
	digits = 170,75,3, standard_font, 1,score;
	DIGITS= 	170,46,3,standard_font,1,show_health;
}

panel backgroundP
{
	window = 10,10,250,100,mainpanel,0,0;
	pos_x=0;
	pos_y=0;
	flags = visible, refresh, overlay;
}



function stabonspike
{
	if(event_type==event_trigger)
	{
		if(you.SKILL9 > -1)
		{
			you.SKILL9 -= 25;
			wait(1);
		}
	}
}

action spike
{
	my.trigger_range = 10;
	my.enable_trigger = on;
	my.event = stabonspike;
}

function rope_action()
{
	while(1)
	{	
		gravity = 0;
		if (key_a && you.z < my.max_z) 
		{
			you.gravity = 0;
			you.z += 0.003;
		}
		if (key_s && you.z > my.min_z) // go down 
		{ 
			you.gravity = 0;
			YOU.Z -= 0.003;
		}
		wait(1);
	}			
}

action rope 
{ 
	my.enable_trigger = on;
	my.trigger_range = 34;
	my.event = rope_action;
} 

//function fallofedgedeath
//{
	//	while(1)
	//	{
		//	if(player.z <= -358.152)
		//	{
			//		player_dead();
		//	}
	//}
//}

//action checkforfalldeath
//{
	//	my.event = fallofedgedeath;
//}

function completedalevel
{
	var timer = 0;

	while(timer<10000)
	{
		camera.pan += 1;
		timer +=1;
	}
	on_anykey = null;
	wait(5);
	level_load(next_level);	
}

action endoflevel
{
	my.trigger_range = 5;
	my.enable_trigger = on;
	my.event = completedalevel;
}


function stabonspike2
{
	if(event_type==event_impact)
	{
		if(you.SKILL9 > -1)
		{
			you.SKILL9 -= 25;
			wait(1);
			my.event = stabonspike2;
		}
	}
}
action swingspike
{
	var whatswing = 1;
	my.enable_impact = on;
	my.enable_entity = on; 
	my.enable_push = on; 
	my.push = -5; 
	my.event = stabonspike2;
	while(1)
	{
		while(whatswing == 1)
		{
			if(my.tilt < my.SKILL2)
			{
				my.tilt += my.SKILL1;
			}
			else
			{
				whatswing = 2;
			}
			wait(1);
		}
		while(whatswing == 2)
		{
			if(my.tilt > -my.SKILL2)
			{
				my.tilt -= my.SKILL1;
			}
			else
			{
				whatswing = 1;
			}
			wait(1);
		}
	}
}
